""" All configuration settings are available here"""

import os

DATA_DOWNLOAD_ROOT = "https://github.com/ageron/handson-ml/master/"
DEFAULT_HOUSING_PATH = "datasets"
HOUSING_URL = DATA_DOWNLOAD_ROOT + "datasets/housing/housing.tgz"


LOGS_PATH = "logs/logs.txt"
